# TPK4186 - Advanced Tools for Performance Engineering
# WeibullDistribution.py
# by Antoine Rauzy
# Copyrights (c) 2019-2020 NTNU
#
# This file is part of the educational material provided to NTNU students registered to the course TPK4186.
# It is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License.
# For details about this license, see https://creativecommons.org/licenses/by-nc/4.0/.

import math
import matplotlib.pyplot as plt

def Weibull(t, alpha, beta):
  return 1 - math.exp(-math.pow(t/alpha, beta))

alpha = 5.0e3
betas = [0.5, 0.75, 1.0, 1.5, 2.0]
colors = ["blue", "orange", "green", "red", "purple"]
lineStyles = []

times = [t for t in range(0, 8770, 10)]
for index in range(0, 5):
  beta = betas[index]
  color = colors[index]
  label = "{0:.2f}".format(beta)
  values = [Weibull(t, alpha, beta) for t in range(0, 8770, 10)]
  plt.plot(times, values, color=color, linestyle='solid', label=label)

plt.title('Weibull distribution for different values of the shape parameter')
plt.ylabel('p')
plt.xlabel('t')
plt.legend()
plt.savefig('WeibullDistribution.pdf')  
plt.show()